@@ -1,4 +1,4 @@
-InitErgm.latent<-function(g, model, k, z.delta=0.1, z.prior.mu=0,
+InitErgmm.latent<-function(g, model, k, z.delta=0.1, z.prior.mu=0,
                           z.prior.sd=10, b.delta=0.5, b.prior.mu=0,
                           b.prior.sd=10,...)
 {
